+++
title = "Preparation"
date = 2017-07-12T17:05:38-04:00
draft = false
+++

1.  Be the root directory for this Hugo site (the directory containing
    `config.toml`).
2.  Run

    ```text
    hugo server --port 1111
    ```
3.  See the site served on "<http://localhost:1111/>".
